@@ -28,8 +28,6 @@ def arg_parse(config_file):
     version_name = args.version
     upload_file_path = args.source
 
-    with open(config_file) as yaml_file:
-        config_file = yaml.load(yaml_file)
 
     if args.check:
         parse_config(config_file)
@@ -51,8 +49,15 @@ def arg_parse(config_file):
         print('zipped_file_path: ', zipped_file_path)
 
         create_zip(zipped_file_path, version_name)
-        push_software(config_file, zipped_file_path, radarType, version_name)
-        remove_zip(zipped_file_path)
+        with open(config_file, "r") as stream:
+            try:
+                config = yaml.safe_load(stream)
+                push_software(config, zipped_file_path, radarType, version_name)
+                remove_zip(zipped_file_path)
+                exit(0)
+            except yaml.YAMLError as exc:
+                print(exc)
+                exit(1)
     else:
         parser.print_help()
         exit(1)
