@@ -1,12 +1,20 @@
 import os
 import requests
+import yaml
 import json
 from .get_bearer_token import get_bearer_token
 
 def push_software(config, fpath, radarType, version_name):
+
     print('Getting the bearer token...')
+    # check config file type
+    if type(config) is not dict:
+        return "Config file is not a dictionary"
+    else:
+        print('config type: ', type(config))
     # check config file
     print('config api_url: ', config['api_url'])
+
     request_url = config['api_url']
 
     bearer_token = get_bearer_token(config)
